@@ -87,7 +87,7 @@ Get_Fragment( void )
   }
 
   /* Goertzel block size depends on Morse speed */
-  block_size = detector_data.frag_len;
+  block_size = detector_data.frag_len * rc_data.unit_elem;
 
   /* Buffer dsp samples of input signal for a fragment */
   for( frag_timer = 0; frag_timer < detector_data.frag_len; frag_timer++ )
